@@ -67,7 +67,13 @@ class CidrAllowList:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CidrAllowList.__init__)
+            def stub(
+                *,
+                cidr_ranges: typing.Sequence[builtins.str],
+                cidr_type: builtins.str,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument cidr_ranges", value=cidr_ranges, expected_type=type_hints["cidr_ranges"])
             check_type(argname="argument cidr_type", value=cidr_type, expected_type=type_hints["cidr_type"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -139,7 +145,13 @@ class CloudFrontWebAclProps:
         if isinstance(cidr_allow_list, dict):
             cidr_allow_list = CidrAllowList(**cidr_allow_list)
         if __debug__:
-            type_hints = typing.get_type_hints(CloudFrontWebAclProps.__init__)
+            def stub(
+                *,
+                cidr_allow_list: typing.Optional[typing.Union[CidrAllowList, typing.Dict[str, typing.Any]]] = None,
+                managed_rules: typing.Optional[typing.Sequence[typing.Union[ManagedRule, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument cidr_allow_list", value=cidr_allow_list, expected_type=type_hints["cidr_allow_list"])
             check_type(argname="argument managed_rules", value=managed_rules, expected_type=type_hints["managed_rules"])
         self._values: typing.Dict[str, typing.Any] = {}
@@ -209,7 +221,15 @@ class CloudfrontWebAcl(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(CloudfrontWebAcl.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                cidr_allow_list: typing.Optional[typing.Union[CidrAllowList, typing.Dict[str, typing.Any]]] = None,
+                managed_rules: typing.Optional[typing.Sequence[typing.Union[ManagedRule, typing.Dict[str, typing.Any]]]] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = CloudFrontWebAclProps(
@@ -250,7 +270,9 @@ class ManagedRule:
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(ManagedRule.__init__)
+            def stub(*, name: builtins.str, vendor: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument name", value=name, expected_type=type_hints["name"])
             check_type(argname="argument vendor", value=vendor, expected_type=type_hints["vendor"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -321,7 +343,13 @@ class RuntimeOptions:
             new StaticWebsite(scope, 'StaticWebsite', {websiteContentPath: 'path/to/website', runtimeConfig});
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(RuntimeOptions.__init__)
+            def stub(
+                *,
+                json_payload: typing.Any,
+                json_file_name: typing.Optional[builtins.str] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument json_payload", value=json_payload, expected_type=type_hints["json_payload"])
             check_type(argname="argument json_file_name", value=json_file_name, expected_type=type_hints["json_file_name"])
         self._values: typing.Dict[str, typing.Any] = {
@@ -413,7 +441,20 @@ class StaticWebsite(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(StaticWebsite.__init__)
+            def stub(
+                scope: constructs.Construct,
+                id: builtins.str,
+                *,
+                website_content_path: builtins.str,
+                default_website_bucket_encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
+                default_website_bucket_encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+                distribution_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.DistributionProps, typing.Dict[str, typing.Any]]] = None,
+                runtime_options: typing.Optional[typing.Union[RuntimeOptions, typing.Dict[str, typing.Any]]] = None,
+                web_acl_props: typing.Optional[typing.Union[CloudFrontWebAclProps, typing.Dict[str, typing.Any]]] = None,
+                website_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument scope", value=scope, expected_type=type_hints["scope"])
             check_type(argname="argument id", value=id, expected_type=type_hints["id"])
         props = StaticWebsiteProps(
@@ -484,7 +525,9 @@ class StaticWebsiteOrigin(
         :stability: experimental
         '''
         if __debug__:
-            type_hints = typing.get_type_hints(StaticWebsiteOrigin.bind)
+            def stub(_scope: constructs.Construct, *, origin_id: builtins.str) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument _scope", value=_scope, expected_type=type_hints["_scope"])
         _options = aws_cdk.aws_cloudfront.OriginBindOptions(origin_id=origin_id)
 
@@ -535,7 +578,18 @@ class StaticWebsiteProps:
         if isinstance(web_acl_props, dict):
             web_acl_props = CloudFrontWebAclProps(**web_acl_props)
         if __debug__:
-            type_hints = typing.get_type_hints(StaticWebsiteProps.__init__)
+            def stub(
+                *,
+                website_content_path: builtins.str,
+                default_website_bucket_encryption: typing.Optional[aws_cdk.aws_s3.BucketEncryption] = None,
+                default_website_bucket_encryption_key: typing.Optional[aws_cdk.aws_kms.Key] = None,
+                distribution_props: typing.Optional[typing.Union[aws_cdk.aws_cloudfront.DistributionProps, typing.Dict[str, typing.Any]]] = None,
+                runtime_options: typing.Optional[typing.Union[RuntimeOptions, typing.Dict[str, typing.Any]]] = None,
+                web_acl_props: typing.Optional[typing.Union[CloudFrontWebAclProps, typing.Dict[str, typing.Any]]] = None,
+                website_bucket: typing.Optional[aws_cdk.aws_s3.IBucket] = None,
+            ) -> None:
+                ...
+            type_hints = typing.get_type_hints(stub)
             check_type(argname="argument website_content_path", value=website_content_path, expected_type=type_hints["website_content_path"])
             check_type(argname="argument default_website_bucket_encryption", value=default_website_bucket_encryption, expected_type=type_hints["default_website_bucket_encryption"])
             check_type(argname="argument default_website_bucket_encryption_key", value=default_website_bucket_encryption_key, expected_type=type_hints["default_website_bucket_encryption_key"])
